==> CGAL-5.2.2-doc_html.tar.xz: doc_html/Barycentric_coordinates_2/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.2.2 - 2D Generalized Barycentric Coordinates", "index.html", [
    [ "User Manual", "index.html", [
      [ "Introduction", "index.html#gbc_introduction", null ],
      [ "Interface", "index.html#gbc_interface", null ],
      [ "Examples", "index.html#gbc_examples", [
        [ "Segment Coordinates", "index.html#seg_example", null ],
        [ "Triangle Coordinates", "index.html#tri_example", null ],
        [ "Wachspress Coordinates", "index.html#wp_example", null ],
        [ "Discrete Harmonic Coordinates", "index.html#dh_example", null ],
        [ "Mean Value Coordinates", "index.html#mv_example", null ],
        [ "Height Interpolation for Terrain Modeling", "index.html#height_inter_example", null ]
      ] ],
      [ "Degeneracies and Special Cases", "index.html#gbc_degeneracies", [
        [ "Segment Coordinates", "index.html#gbc_deg_segment_coordinates", null ],
        [ "Triangle Coordinates", "index.html#gbc_deg_triangular_coordinates", null ],
        [ "Wachspress Coordinates", "index.html#gbc_deg_wachspress_coordinates", null ],
        [ "Discrete Harmonic Coordinates", "index.html#gbc_deg_discrete_harmonic_coordinates", null ],
        [ "Mean Value Coordinates", "index.html#gbc_deg_mean_value_coordinates", null ]
      ] ],
      [ "Performance", "index.html#gbc_performance", null ],
      [ "Implementation Details", "index.html#gbc_implementation", null ],
      [ "Theory of 2D Generalized Barycentric Coordinates", "index.html#gbc_theory", null ],
      [ "Acknowledgments", "index.html#gbc_acknowledgments", null ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
".html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> CGAL-5.4.1-doc_html.tar.xz: doc_html/Barycentric_coordinates_2/navtreedata.js <==
var NAVTREE =
[
  [ "CGAL 5.4.1 - 2D Generalized Barycentric Coordinates", "index.html", [
    [ "User Manual", "index.html", [
      [ "Introduction", "index.html#gbc_introduction", null ],
      [ "Software Design", "index.html#gbc_interface", null ],
      [ "Examples", "index.html#gbc_examples", [
        [ "Segment Coordinates", "index.html#seg_example", null ],
        [ "Triangle Coordinates", "index.html#tri_example", null ],
        [ "Wachspress Coordinates", "index.html#wp_example", null ],
        [ "Discrete Harmonic Coordinates", "index.html#dh_example", null ],
        [ "Mean Value Coordinates", "index.html#mv_example", null ],
        [ "Harmonic Coordinates", "index.html#hm_example", null ],
        [ "Terrain Modeling", "index.html#height_inter_example", null ],
        [ "Shape Deformation", "index.html#shape_deform_example", null ],
        [ "Affine Coordinates", "index.html#aff_example", null ],
        [ "Deprecated Coordinates", "index.html#depr_example", null ]
      ] ],
      [ "Edge Cases", "index.html#gbc_degeneracies", [
        [ "Segment Coordinates", "index.html#gbc_deg_segment_coordinates", null ],
        [ "Triangle Coordinates", "index.html#gbc_deg_triangular_coordinates", null ],
        [ "Wachspress Coordinates", "index.html#gbc_deg_wachspress_coordinates", null ],
        [ "Discrete Harmonic Coordinates", "index.html#gbc_deg_discrete_harmonic_coordinates", null ],
        [ "Mean Value Coordinates", "index.html#gbc_deg_mean_value_coordinates", null ],
        [ "Harmonic Coordinates", "index.html#gbc_deg_harmonic_coordinates", null ]
      ] ],
      [ "Performance", "index.html#gbc_performance", null ],
      [ "History", "index.html#gbc_history", null ],
      [ "Acknowledgments", "index.html#gbc_acknowledgments", null ]
    ] ],
    [ "Reference Manual", "modules.html", "modules" ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Is Model Relationships", "models.html", null ],
    [ "Has Model Relationships", "hasModels.html", null ],
    [ "Bibliography", "citelist.html", null ],
    [ "Class and Concept List", "annotated.html", "annotated" ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
".html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
